define('dojo/nls/pmbdijit_es-es',{
'dijit/nls/loading':{"loadingState":"Cargando...","errorState":"Lo siento, se ha producido un error","_localized":{}}
,
'dijit/form/nls/validate':{"invalidMessage":"El valor especificado no es válido.","missingMessage":"Este valor es necesario.","rangeMessage":"Este valor está fuera del intervalo.","_localized":{}}
,
'dojo/cldr/nls/number':{"scientificFormat":"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]","infinity":"∞","superscriptingExponent":"×","list":";","percentSign":"%","minusSign":"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000B","currencySpacing-afterCurrency-insertBetween":" ","nan":"NaN","plusSign":"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]","currencyFormat":"#,##0.00 ¤","perMille":"‰","group":".","percentFormat":"#,##0%","decimalFormat-long":"000 billones","decimalFormat":"#,##0.###","decimal":",","currencySpacing-beforeCurrency-insertBetween":" ","exponential":"E","_localized":{}}
,
'dijit/nls/common':{"buttonOk":"Aceptar","buttonCancel":"Cancelar","buttonSave":"Guardar","itemClose":"Cerrar","_localized":{}}
,
'dijit/_editor/nls/commands':{"bold":"Negrita","copy":"Copiar","cut":"Cortar","delete":"Suprimir","indent":"Sangría","insertHorizontalRule":"Regla horizontal","insertOrderedList":"Lista numerada","insertUnorderedList":"Lista con viñetas","italic":"Cursiva","justifyCenter":"Alinear centro","justifyFull":"Justificar","justifyLeft":"Alinear izquierda","justifyRight":"Alinear derecha","outdent":"Anular sangría","paste":"Pegar","redo":"Rehacer","removeFormat":"Eliminar formato","selectAll":"Seleccionar todo","strikethrough":"Tachado","subscript":"Subíndice","superscript":"Superíndice","underline":"Subrayado","undo":"Deshacer","unlink":"Eliminar enlace","createLink":"Crear enlace","toggleDir":"Conmutar dirección","insertImage":"Insertar imagen","insertTable":"Insertar/Editar tabla","toggleTableBorder":"Conmutar borde de tabla","deleteTable":"Suprimir tabla","tableProp":"Propiedad de tabla","htmlToggle":"Fuente HTML","foreColor":"Color de primer plano","hiliteColor":"Color de segundo plano","plainFormatBlock":"Estilo de párrafo","formatBlock":"Estilo de párrafo","fontSize":"Tamaño de font","fontName":"Nombre de font","tabIndent":"Sangría de tabulador","fullScreen":"Conmutar pantalla completa","viewSource":"Ver fuente HTML","print":"Imprimir","newPage":"Nueva página","systemShortcut":"La acción \"${0}\" sólo está disponible en su navegador mediante un atajo de teclado. Utilice ${1}.","ctrlKey":"control+${0}","appleKey":"⌘${0}","_localized":{}}
,
'dijit/form/nls/ComboBox':{"previousMessage":"Opciones anteriores","nextMessage":"Más opciones","_localized":{}}
,
'dijit/_editor/nls/FontChoice':{"1":"xx-pequeño","2":"x-pequeño","3":"pequeño","4":"medio","5":"grande","6":"x-grande","7":"xx-grande","fontSize":"Tamaño","fontName":"Font","formatBlock":"Formato","serif":"serif","sans-serif":"sans-serif","monospace":"espacio sencillo","cursive":"cursiva","fantasy":"fantasía","noFormat":"Ninguno","p":"Párrafo","h1":"Cabecera","h2":"Subcabecera","h3":"Sub-subcabecera","pre":"Preformateado","_localized":{}}
,
'dojox/editor/plugins/nls/latinEntities':{"iexcl":"signo de exclamación inicial","cent":"símbolo de centavos","pound":"símbolo libra esterlina","curren":"símbolo monetario","yen":"símbolo del yen\nsímbolo del yuan","brvbar":"barra dividida\nbarra vertical dividida","sect":"signo de sección","uml":"diéresis\ndiéresis de espaciado","copy":"símbolo de copyright","ordf":"indicador de ordinal femenino","laquo":"comillas dobles en ángulo a la izquierda","not":"signo de negación","shy":"signo de guión corto","reg":"símbolo de registrado\nsímbolo de marca registrada","macr":"macron\nmacro de espaciado\nsobrelínea\nsobrebarra APL","deg":"signo de grados","plusmn":"signo de más-menos\nsigno de más o menos","sup2":"superíndice dos\nsuperíndice de dígito dos\nal guardado","sup3":"superíndice tres\nsuperíndice de dígito tres\nal cubo","acute":"acento agudo\nagudo de espaciado","micro":"signo de micro","para":"signo de párrafo","middot":"punto medio\ncoma georgina\npunto medio griego","cedil":"cedilla\ncedilla de espaciado","sup1":"superíndice uno\nsuperíndice de dígito uno","ordm":"indicador de ordinal masculino","raquo":"comillas dobles en ángulo a la derecha","frac14":"fracción de cuarto vulgar\nfracción de cuarto","frac12":"fracción de medio vulgar\nfracción de medio","frac34":"fracción de tres cuartos vulgar\nfracción de tres cuartos","iquest":"signo de interrogación inicial\nsigno de apertura de interrogación","Agrave":"letra A latina mayúscula con acento grave\nletra A latina mayúscula grave","Aacute":"letra A latina mayúscula con acento agudo","Acirc":"letra A latina mayúscula con acento circunflejo","Atilde":"letra A latina mayúscula con virgulilla\nletra A latina mayúscula con tilde","Auml":"letra A latina mayúscula con diéresis","Aring":"letra A latina mayúscula con anillo encima\nletra A latina mayúscula con anillo","AElig":"diptongo AE latinas mayúsculas\nligadura de AE latinas mayúsculas","Ccedil":"letra C latina mayúscula con cedilla","Egrave":"letra E latina mayúscula con acento grave","Eacute":"letra E latina mayúscula con acento agudo","Ecirc":"letra E latina mayúscula con acento circunflejo","Euml":"letra E latina mayúscula con acento diéresis","Igrave":"letra I latina mayúscula con acento grave","Iacute":"letra I latina mayúscula con acento agudo","Icirc":"letra I latina mayúscula con acento circunflejo","Iuml":"letra I latina mayúscula con diéresis","ETH":"letra ETH latina mayúscula","Ntilde":"letra N latina mayúscula con virgulilla\nletra N latina mayúscula con tilde\nletra Ñ latina mayúscula","Ograve":"letra O latina mayúscula con acento grave","Oacute":"letra O latina mayúscula con acento agudo","Ocirc":"letra O latina mayúscula con acento circunflejo","Otilde":"letra O latina mayúscula con virgulilla\nletra O latina mayúscula con tilde","Ouml":"letra O latina mayúscula con diéresis","times":"signo de multiplicación","Oslash":"letra O latina mayúscula con barra\nletra O latina mayúscula con barra inclinada","Ugrave":"letra U latina mayúscula con acento grave","Uacute":"letra U latina mayúscula con acento agudo","Ucirc":"letra U latina mayúscula con acento circunflejo","Uuml":"letra U latina mayúscula con diéresis","Yacute":"letra Y latina mayúscula con acento agudo","THORN":"letra THORN latina mayúscula","szlig":"letra s fuerte latina minúscula\nEszet","agrave":"letra a latina minúscula con acento grave\nletra a latina minúscula grave","aacute":"letra a latina minúscula con acento agudo","acirc":"letra a latina minúscula con acento circunflejo","atilde":"letra a latina minúscula con virgulilla\nletra a latina minúscula con tilde","auml":"letra a latina minúscula con diéresis","aring":"letra a latina minúscula con anillo encima\nletra a latina minúscula con anillo","aelig":"Diptongo ae latinas minúsculas\nligadura de ae latinas minúsculas","ccedil":"letra c latina minúscula con cedilla","egrave":"letra e latina minúscula con acento grave","eacute":"letra e latina minúscula con acento agudo","ecirc":"letra e latina minúscula con acento circunflejo","euml":"letra e latina minúscula con diéresis","igrave":"letra i latina minúscula con acento grave","iacute":"letra i latina minúscula con acento agudo","icirc":"letra i latina minúscula con acento circunflejo","iuml":"letra i latina minúscula con diéresis","eth":"letra eth latina minúscula","ntilde":"letra n latina minúscula con virgulilla\nletra n latina minúscula con tilde","ograve":"letra o latina minúscula con acento grave","oacute":"letra o latina minúscula con acento agudo","ocirc":"letra o latina minúscula con acento circunflejo","otilde":"letra o latina minúscula con virgulilla\nletra o latina minúscula con tilde","ouml":"letra o latina minúscula con diéresis","divide":"signo de división","oslash":"letra o latina minúscula con barra\nletra o latina minúscula con barra inclinada","ugrave":"letra u latina minúscula con acento grave","uacute":"letra u latina minúscula con acento agudo","ucirc":"letra u latina minúscula con acento circunflejo","uuml":"letra u latina minúscula con diéresis","yacute":"letra y latina minúscula con acento agudo","thorn":"letra thorn latina minúscula","yuml":"letra y latina minúscula con diéresis","fnof":"letra f latina minúscula con gancho\nfunción\nflorín","Alpha":"letra alpha griega mayúscula","Beta":"letra beta griega mayúscula","Gamma":"letra gamma griega mayúscula","Delta":"letra delta griega mayúscula","Epsilon":"letra épsilon griega mayúscula","Zeta":"letra zeta griega mayúscula","Eta":"letra eta griega mayúscula","Theta":"letra theta griega mayúscula","Iota":"letra iota griega mayúscula","Kappa":"letra kappa griega mayúscula","Lambda":"letra lambda griega mayúscula","Mu":"letra mu griega mayúscula","Nu":"letra nu griega mayúscula","Xi":"letra xi griega mayúscula","Omicron":"letra ómicron griega mayúscula","Pi":"letra pi griega mayúscula","Rho":"letra rho griega mayúscula","Sigma":"letra sigma griega mayúscula","Tau":"letra tau griega mayúscula","Upsilon":"letra ípsilon griega mayúscula","Phi":"letra phi griega mayúscula","Chi":"letra chi griega mayúscula","Psi":"letra psi griega mayúscula","Omega":"letra omega griega mayúscula","alpha":"letra alpha griega minúscula","beta":"letra beta griega minúscula","gamma":"letra gamma griega minúscula","delta":"letra delta griega minúscula","epsilon":"letra épsilon griega minúscula","zeta":"letra zeta griega minúscula","eta":"letra eta griega minúscula","theta":"letra theta griega minúscula","iota":"letra iota griega minúscula","kappa":"letra kappa griega minúscula","lambda":"letra lambda griega minúscula","mu":"letra mu griega minúscula","nu":"letra nu griega minúscula","xi":"letra xi griega minúscula","omicron":"letra ómicron griega minúscula","pi":"letra pi griega minúscula","rho":"letra rho griega minúscula","sigmaf":"letra sigma final griega minúscula","sigma":"letra sigma griega minúscula","tau":"letra tau griega minúscula","upsilon":"letra ípsilon griega minúscula","phi":"letra phi griega minúscula","chi":"letra chi griega minúscula","psi":"letra psi griega minúscula","omega":"letra omega griega minúscula","thetasym":"símbolo de letra theta griega minúscula","upsih":"símbolo de letra ípsilon griega con gancho","piv":"símbolo pi griego","bull":"viñeta\ncírculo negro pequeño","hellip":"puntos suspensivos","prime":"primero\nminutos\npie","Prime":"primero doble\nsegundos\npulgadas","oline":"sobrelínea\nsobresubrayado de espaciado","frasl":"barra de fracción","weierp":"P mayúsculas de script\nvalor nominal\nWeierstrass p","image":"letra I gótica\nnúmeros imaginarios","real":"letra R gótica\nsímbolo real","trade":"símbolo de marca registrada","alefsym":"símbolo alef\nprimer cardinal transfinito","larr":"flecha a la izquierda","uarr":"flecha hacia arriba","rarr":"flecha a la derecha","darr":"flecha hacia abajo","harr":"flecha izquierda-derecha","crarr":"flecha esquinada abajo a la izquierda\nretorno de carro","lArr":"doble flecha a la izquierda","uArr":"doble flecha hacia arriba","rArr":"doble flecha a la derecha","dArr":"doble flecha hacia abajo","hArr":"doble flecha izquierda-derecha","forall":"para todo","part":"derivada parcial","exist":"existe","empty":"conjunto vacío\nconjunto nulo\ndiámetro","nabla":"nabla\ndiferencia hacia atrás","isin":"pertenece","notin":"no pertenece","ni":"está incluido","prod":"producto núm. n\nsímbolo de multiplicación","sum":"sumatoria","minus":"signo menos","lowast":"operador asterisco","radic":"raíz cuadrada\nsímbolo de radical","prop":"proporcional","infin":"infinito","ang":"ángulo","and":"y lógico\ncuña","or":"o lógico\nvee","cap":"intersección\ncap","cup":"unión\ncup","int":"integral","there4":"por lo tanto","sim":"operador de tilde\nvaría con\nsimilar a","cong":"aproximadamente igual a","asymp":"casi igual a\nasimtótico a","ne":"no igual a","equiv":"idéntico a","le":"menor o igual que","ge":"mayor o igual que","sub":"subconjunto de","sup":"superconjunto de","nsub":"no un subconjunto de","sube":"subconjunto de o igual a","supe":"superconjunto de o igual a","oplus":"más en círculo\nsuma directa","otimes":"veces en círculo\nproducto de vector","perp":"tachuela arriba\nortogonal a\nperpendicular","sdot":"operador punto","lceil":"límite superior izquierdo\nmontante arriba APL","rceil":"parte superior de corchete cerrado","lfloor":"límite inferior derecho\nmontaje abajo APL","rfloor":"parte inferior de corchete abierto","lang":"corchete angular hacia la izquierda","rang":"corchete angular hacia la derecha","loz":"rombo","spades":"palo de picas","clubs":"palo de tréboles","hearts":"palo de corazones","diams":"palo de diamantes","OElig":"ligadura de OE latinas mayúsculas","oelig":"ligadura de oe latinas minúsculas","Scaron":"letra S latina mayúscula con anticircunflejo","scaron":"letra s latina minúscula con anticircunflejo","Yuml":"letra Y latina mayúscula con diéresis","circ":"acento circunflejo","tilde":"tilde pequeña","ensp":"espacio","emsp":"espacio largo","thinsp":"espacio estrecho","zwnj":"separador de anchura cero","zwj":"conector de anchura cero","lrm":"marca de izquierda a derecha","rlm":"marca de derecha a izquierda","ndash":"guión","mdash":"guión largo","lsquo":"comilla simple abierta","rsquo":"comilla simple cerrada","sbquo":"comilla simple inferior","ldquo":"comillas dobles abiertas","rdquo":"comillas dobles cerradas","bdquo":"comillas dobles inferiores","dagger":"daga","Dagger":"daga doble","permil":"signo de por mil","lsaquo":"comilla simple angular abierta","rsaquo":"comilla simple angular cerrada","euro":"signo del euro","_localized":{}}
,
'dojox/editor/plugins/nls/InsertEntity':{"insertEntity":"Insertar símbolo","_localized":{}}
,
'dojo/nls/colors':{"aliceblue":"blanco azulado","antiquewhite":"blanco antiguo","aqua":"aguamarina","aquamarine":"aguamarina 2","azure":"blanco cielo","beige":"beige","bisque":"miel","black":"negro","blanchedalmond":"almendra pálido","blue":"azul","blueviolet":"azul violáceo","brown":"marrón","burlywood":"madera","cadetblue":"azul cadete","chartreuse":"verde pálido 2","chocolate":"chocolate","coral":"coral","cornflowerblue":"azul aciano","cornsilk":"crudo","crimson":"carmesí","cyan":"cian","darkblue":"azul oscuro","darkcyan":"cian oscuro","darkgoldenrod":"ocre oscuro","darkgray":"gris oscuro","darkgreen":"verde oscuro","darkgrey":"gris oscuro","darkkhaki":"caqui oscuro","darkmagenta":"magenta oscuro","darkolivegreen":"verde oliva oscuro","darkorange":"naranja oscuro","darkorchid":"orquídea oscuro","darkred":"rojo oscuro","darksalmon":"salmón oscuro","darkseagreen":"verde mar oscuro","darkslateblue":"azul pizarra oscuro","darkslategray":"gris pizarra oscuro","darkslategrey":"gris pizarra oscuro","darkturquoise":"turquesa oscuro","darkviolet":"violeta oscuro","deeppink":"rosa fuerte","deepskyblue":"azul cielo fuerte","dimgray":"gris marengo","dimgrey":"gris marengo","dodgerblue":"azul fuerte","firebrick":"teja","floralwhite":"blanco manteca","forestgreen":"verde pino","fuchsia":"fucsia","gainsboro":"azul gainsboro","ghostwhite":"blanco ligero","gold":"oro","goldenrod":"ocre","gray":"gris","green":"verde","greenyellow":"amarillo verdoso","grey":"gris","honeydew":"flor de rocío","hotpink":"rosa oscuro","indianred":"rojo teja","indigo":"añil","ivory":"marfil","khaki":"caqui","lavender":"lavanda","lavenderblush":"lavanda rosácea","lawngreen":"verde césped","lemonchiffon":"amarillo pastel","lightblue":"azul claro","lightcoral":"coral claro","lightcyan":"cian claro","lightgoldenrodyellow":"ocre claro","lightgray":"gris claro","lightgreen":"verde claro","lightgrey":"gris claro","lightpink":"rosa claro","lightsalmon":"salmón claro","lightseagreen":"verde mar claro","lightskyblue":"azul cielo claro","lightslategray":"gris pizarra claro","lightslategrey":"gris pizarra claro","lightsteelblue":"azul acero claro","lightyellow":"amarillo claro","lime":"lima","limegreen":"lima limón","linen":"blanco arena","magenta":"magenta","maroon":"granate","mediumaquamarine":"aguamarina medio","mediumblue":"azul medio","mediumorchid":"orquídea medio","mediumpurple":"púrpura medio","mediumseagreen":"verde mar medio","mediumslateblue":"azul pizarra medio","mediumspringgreen":"verde primavera medio","mediumturquoise":"turquesa medio","mediumvioletred":"rojo violáceo medio","midnightblue":"azul medianoche","mintcream":"crema menta","mistyrose":"rosa difuminado","moccasin":"arena","navajowhite":"blanco navajo","navy":"azul marino","oldlace":"encaje antiguo","olive":"verde oliva","olivedrab":"verde oliva pardusco","orange":"naranja","orangered":"rojo anaranjado","orchid":"orquídea","palegoldenrod":"ocre pálido","palegreen":"verde pálido","paleturquoise":"turquesa pálido","palevioletred":"rojo violáceo pálido","papayawhip":"papaya claro","peachpuff":"melocotón","peru":"perú","pink":"rosa","plum":"ciruela","powderblue":"azul suave","purple":"púrpura","red":"rojo","rosybrown":"marrón rosáceo","royalblue":"azul real","saddlebrown":"cuero","salmon":"salmón","sandybrown":"marrón arcilla","seagreen":"verde mar","seashell":"blanco marfil","sienna":"siena","silver":"plateado","skyblue":"azul cielo","slateblue":"azul pizarra","slategray":"gris pizarra","slategrey":"gris pizarra","snow":"nieve","springgreen":"verde fuerte","steelblue":"azul acero","tan":"canela","teal":"verde azulado","thistle":"cardo","tomato":"tomate","transparent":"transparente","turquoise":"turquesa","violet":"violeta","wheat":"trigo","white":"blanco","whitesmoke":"blanco ahumado","yellow":"amarillo","yellowgreen":"verde amarillento","_localized":{}}
,
'dojox/widget/nls/ColorPicker':{"redLabel":"r","greenLabel":"v","blueLabel":"a","hueLabel":"m","saturationLabel":"s","valueLabel":"v","degLabel":"°","hexLabel":"hex","huePickerTitle":"Selector de tono","saturationPickerTitle":"Selector de saturación","_localized":{}}
,
'dojox/editor/plugins/nls/TableDialog':{"insertTableTitle":"Insertar tabla","modifyTableTitle":"Modificar tabla","rows":"Filas:","columns":"Columnas:","align":"Alinear:","cellPadding":"Relleno de celda:","cellSpacing":"Espaciado de celda:","tableWidth":"Ancho de tabla:","backgroundColor":"Color de fondo:","borderColor":"Color de borde:","borderThickness":"Grosor del borde:","percent":"por ciento","pixels":"píxeles","default":"default","left":"izquierda","center":"centro","right":"derecha","buttonSet":"Establecer","buttonInsert":"Insertar","buttonCancel":"Cancelar","selectTableLabel":"Seleccionar tabla","insertTableRowBeforeLabel":"Añadir fila antes","insertTableRowAfterLabel":"Añadir fila después","insertTableColumnBeforeLabel":"Añadir columna antes","insertTableColumnAfterLabel":"Añadir columna después","deleteTableRowLabel":"Suprimir fila","deleteTableColumnLabel":"Suprimir columna","colorTableCellTitle":"Celda de tabla de color de fondo","tableContextMenuTitle":"Menú contextual de la tabla","_localized":{}}
,
'dojox/editor/plugins/nls/PasteFromWord':{"pasteFromWord":"Pegar desde Word","instructions":"Pegue el contenido de Word en el siguiente recuadro de texto. Cuando esté satisfecho con el contenido que se debe insertar, pulse el botón pegar. Para abortar la inserción de texto, pulse el botón cancelar.","_localized":{}}
,
'dojox/editor/plugins/nls/InsertAnchor':{"insertAnchor":"Insertar ancla","title":"Propiedades del ancla","anchor":"Nombre:","text":"Descripción:","set":"Establecer","cancel":"Cancelar","_localized":{}}
,
'dojox/editor/plugins/nls/Blockquote':{"blockquote":"Cita en bloque","_localized":{}}
,
'dojox/editor/plugins/nls/LocalImage':{"insertImageTitle":"Insertar imagen","url":"Imagen","browse":"Examinar...","text":"Descripción","set":"Insertar","invalidMessage":"Tipo de archivo de imagen no válido","prePopuTextUrl":"Especifique un URL de imagen","prePopuTextBrowse":" o seleccione un archivo local.","_localized":{}}
});